translate.storage.wordfast.WordfastHeader

Package translate :: Package storage :: Module wordfast :: Class WordfastHeader |
[hide private]
[frames] | no frames]

# Class WordfastHeader

source code

A wordfast translation memory header

Instance Methods | [hide private]
__init__(self, header=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_create_default_header(self) Create a default Wordfast header with the date set to the current time | source code
getheader(self) Get the header dictionary | source code
setheader(self, newheader) | source code
settargetlang(self, newlang) | source code
settucount(self, count) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| header = `property(getheader, setheader)`
| targetlang = `property(None, settargetlang)`
| tucount = `property(None, settucount)`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, header=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)